@@ -26,7 +26,7 @@ copyright = '2020, Mark Taylor'
 author = 'Mark Taylor'
 
 # The full version, including alpha/beta/rc tags
-release = '0.1.0'
+release = '1.0.0'
 
 
 # -- General configuration ---------------------------------------------------
@@ -61,7 +61,9 @@ exclude_patterns = [
     'tests', 'src',
     '.tox',
     '.pytest_cache',
-    '_build', 'Thumbs.db', '.DS_Store'
+    '_build', 'Thumbs.db', '.DS_Store',
+    # for personal dev environments
+    '.export*'
 ]
 
 master_doc = 'index'
