@@ -42,14 +42,18 @@ defenestrate 12
     line_by_line_compare_exact(a=expected_str, b=capsys.readouterr().out)
 
 
-def session_00001_line_72():
+def session_00001_line_75():
     r"""
-    >>> print('Greetings Planet!')
-    Greetings Planet!
+    >>> a = 'Greetings Planet!'
+    >>> a
+    'Greetings Planet!'
+    >>> b = 12
+    >>> b
+    12
     """
 
 
-def test_code_80_output_86(capsys):
+def test_code_87_output_93(capsys):
     from datetime import date
     d = date.fromordinal(730920)    # 730920th day after 1. 1. 0001
     print(d)
