@@ -9,9 +9,12 @@ import commonmark.node    # type: ignore
 def fenced_code_blocks(markdown_filename: str) -> List[str]:
     """Return Markdown fenced code block contents as a list of strings.
 
-    markdown_filename : Path to the Markdown file.
+    Args:
+        markdown_filename
+            Path to the Markdown file.
 
-    Returns a list of strings, one for the contents of each Markdown
+    Returns:
+        List of strings, one for the contents of each Markdown
         fenced code block.
     """
     with open(markdown_filename, encoding='utf-8') as fp:
@@ -22,9 +25,12 @@ def fenced_code_blocks(markdown_filename: str) -> List[str]:
 def fenced_block_nodes(fp: IO[str]) -> List[commonmark.node.Node]:
     """Get markdown fenced code blocks as list of Node objects.
 
-    fp : file object returned by open().
+    Args:
+        fp
+            file object returned by open().
 
-    Returns a list of commonmark.node.Node objects.
+    Returns:
+         List of commonmark.node.Node objects.
     """
     nodes = []
     doc = fp.read()
