@@ -8,7 +8,6 @@ import pytest
 
 import phmdoctest.main
 import phmdoctest.simulator
-import phmdoctest.print_capture
 import phmdoctest.tool
 import verify
 
@@ -41,7 +40,7 @@ def setup_module():
 def test_raw_example1_md():
     """README raw markdown is same as file doc/example1.md."""
     want = next(readme_blocks)
-    with open('doc/example1.md') as fp:
+    with open('doc/example1.md', 'r', encoding='utf-8') as fp:
         got = fp.read()
         verify.a_and_b_are_the_same(want, got)
 
@@ -61,7 +60,7 @@ def test_example1():
     )
     # Make sure the copy of test_example1.py in README.md
     # is the same as the disk file.
-    with open('doc/test_example1.py') as fp:
+    with open('doc/test_example1.py', 'r', encoding='utf-8') as fp:
         got = fp.read()
         verify.a_and_b_are_the_same(want, got)
 
@@ -107,6 +106,47 @@ def test_skip_example():
     verify.a_and_b_are_the_same(want, got2)
 
 
+def test_setup_first_fcb():
+    """Make sure example setup fenced code block same as in the file."""
+    want = next(readme_blocks)    # get the setup block example
+    blocks = phmdoctest.tool.fenced_code_blocks('doc/setup.md')
+    got = blocks[0]
+    verify.a_and_b_are_the_same(want, got)
+
+
+def test_setup_report_example():
+    """Make sure report in README is correct."""
+    command = next(readme_blocks)
+    want = next(readme_blocks)    # get the report
+    simulator_status = verify.one_example(
+        command,
+        want_file_name=None,
+        pytest_options=None
+    )
+    got1 = simulator_status.runner_status.stdout
+    verify.a_and_b_are_the_same(want, got1)
+
+
+def test_setup():
+    """Make sure --setup --outfile is correct."""
+    command = next(readme_blocks)
+    _ = verify.one_example(
+        command,
+        want_file_name='doc/test_setup.py',
+        pytest_options=None
+    )
+
+
+def test_setup_doctest():
+    """Make sure --setup-doctest --outfile is correct."""
+    command = next(readme_blocks)
+    _ = verify.one_example(
+        command,
+        want_file_name='doc/test_setup_doctest.py',
+        pytest_options=None
+    )
+
+
 def test_outfile_to_stdout():
     """Make sure generated --outfile and --report are as expected."""
     outfile_command1 = next(readme_blocks)
@@ -116,7 +156,7 @@ def test_outfile_to_stdout():
         want_file_name=None,
         pytest_options=None
     )
-    with open('doc/test_example2.py') as fp:
+    with open('doc/test_example2.py', 'r', encoding='utf-8') as fp:
         want = fp.read()
     got1 = simulator_status.runner_status.stdout
     verify.a_and_b_are_the_same(want, got1)
@@ -175,7 +215,7 @@ matrix:
         assert travis_text.startswith(expected)
 
 
-# Developers: Changes here must be mirrored in a fenced code block in README.md.
+# Developers: Changes here must be mirrored in a Markdown FCB in README.md.
 # Runnable version of example code in README.md.
 # The guts of this function are an exact copy of example in README.md.
 def example_code():
